<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddCaracteristique extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("caracteristique", ['id' => false, 'primary_key' => ["caracteristique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('caracteristique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('caracteristique_rang', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_id'])
            ->addColumn('caracteristique_prefix', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_rang'])
            ->addColumn('caracteristique_ouverture', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_prefix'])
            ->addColumn('caracteristique_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_ouverture'])
            ->addColumn('caracteristique_template', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_statut_id', 'signed' => false])
            ->addIndex(['caracteristique_rang'], ['name' => "caracteristique_rang", 'unique' => false])
            ->addIndex(['caracteristique_statut_id'], ['name' => "caracteristique_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("caracteristique_nom", ['id' => false, 'primary_key' => ["caracteristique_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('caracteristique_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('caracteristique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_nom_id', 'signed' => false])
            ->addColumn('caracteristique_nom_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_id'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_nom_nom', 'signed' => false])
            ->addForeignKey('caracteristique_id', 'caracteristique', 'caracteristique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['caracteristique_id'], ['name' => "caracteristique_id", 'unique' => false])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['caracteristique_nom_nom'], ['name' => "caracteristique_nom_nom", 'unique' => false])
            ->addIndex(['caracteristique_id', 'langue_id'], ['name' => "caracteristique_id_2", 'unique' => true])
            ->create();

        $this
            ->table("caracteristique_valeur", ['id' => false, 'primary_key' => ["caracteristique_valeur_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('caracteristique_valeur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('caracteristique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_id', 'signed' => false])
            ->addColumn('caracteristique_valeur_code', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_id'])
            ->addColumn('caracteristique_valeur_couleur', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_code'])
            ->addColumn('caracteristique_valeur_image', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_couleur'])
            ->addColumn('caracteristique_valeur_rang', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_image'])
            ->addColumn('caracteristique_valeur_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_rang'])
            ->addColumn('caracteristique_valeur_visible_filtre', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_statut_id'])
            ->addForeignKey('caracteristique_id', 'caracteristique', 'caracteristique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['caracteristique_id'], ['name' => "caracteristique_id", 'unique' => false])
            ->addIndex(['caracteristique_valeur_rang'], ['name' => "caracteristique_valeur_rang", 'unique' => false])
            ->addIndex(['caracteristique_valeur_statut_id'], ['name' => "caracteristique_valeur_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("caracteristique_valeur_nom", ['id' => false, 'primary_key' => ["caracteristique_valeur_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('caracteristique_valeur_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('caracteristique_valeur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_nom_id', 'signed' => false])
            ->addColumn('caracteristique_valeur_nom_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_id'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'caracteristique_valeur_nom_nom', 'signed' => false])
            ->addColumn('caracteristique_valeur_nom_image', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'langue_id'])
            ->addColumn('caracteristique_valeur_nom_desc', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_nom_image'])
            ->addColumn('caracteristique_valeur_nom_tag', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_nom_desc'])
            ->addColumn('caracteristique_valeur_nom_menu', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'caracteristique_valeur_nom_tag'])
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('caracteristique_valeur_id', 'caracteristique_valeur', 'caracteristique_valeur_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['caracteristique_valeur_id'], ['name' => "caracteristique_valeur_id", 'unique' => false])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['caracteristique_valeur_nom_nom'], ['name' => "caracteristique_valeur_nom_nom", 'unique' => false])
            ->addIndex(['caracteristique_valeur_id', 'langue_id'], ['name' => "caracteristique_valeur_id_2", 'unique' => true])
            ->create();
    }
}
