<?php

namespace Auth;

use DediException;
use Application;
use Event\AuthEvent;
use Symfony\Component\HttpFoundation\Request;

class Auth {

    /**
     * @var Auth
     */
    static protected $instance = null;

    /**
     * @var array
     */
    protected $callbacks;

    /**
     * @var \Symfony\Component\HttpFoundation\Request
     */
    protected $request;

    private function __construct()
    {
        Application::getEventDispatcher()->dispatch(AuthEvent::LOAD, new AuthEvent($this));
    }

    /**
     * @return Auth
     */
    public static function getInstance()
    {
        if (!(self::$instance instanceof self)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * register callback on role
     *
     * @param $roleName
     * @param $callback
     *
     * @return $this
     */
    public function register($roleName, $callback)
    {
        $this->callbacks[$roleName] = $callback;
        return $this;
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function setRequest(Request $request)
    {
        $this->request = $request;
        return $this;
    }

    /**
     * @return Request
     */
    public function getRequest()
    {
        return $this->request;
    }

    /**
     * Check the role, call the callback register previously for the role
     *
     * @param $roleName
     *
     * @return mixed
     *
     * @throws DediException
     */
    public function checkRole($roleName)
    {
        if (empty($roleName)) {
            throw new DediException('role name must be fill');
        }

        if (empty($this->callbacks[$roleName])) {
            throw new DediException('no callback for this role name');
        }

        list($class, $method) = $this->callbacks[$roleName];
        return call_user_func_array(array(new $class, $method), array($this, $roleName));
    }

}