<?php

declare(strict_types=1);

namespace Controller;

use Symfony\Component\HttpFoundation\Response;
use Texte;
use Breadcrumb;

/**
 * Class ErrorController
 * @package Controller
 */
class ErrorController extends Controller
{
    /**
     * @return Response
     * @throws \SmartyException
     */
    public function error_404(): Response
    {
        $texte = new Texte();

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('page_404', 'Erreur 404'));

        $tplVars = [
            'message' => $texte->getOneOrCreate('message_404', "Oups, la page demandée n'existe pas")
        ];

        return $this->render('error.tpl', $tplVars, 404);
    }

    /**
     * @param string|null $detail
     *
     * @return Response
     * @throws \SmartyException
     */
    public function error_500(string $detail = ""): Response
    {
        $texte = new Texte();

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('page_500', 'Erreur 500'));

        $this->template->assign('message', $texte->getOneOrCreate('message_500', "Une erreur interne est survenue"));
        $this->template->assign('detail', $detail);

        return new Response($this->template->fetch('error.tpl'), 500);
    }
}
