<?php

namespace ProduitList;

abstract class ProduitList extends \Model
{
    protected $table = "produit_list";

    /**
     * @var array
     */
    protected $produits;

    public function __construct($id = null)
    {
        $this->produits = array();
        $this->produit_list_type_id = $this->typeId;
        parent::__construct($id);
    }

    public function getProdQuery(){
        $query = new \Query();
        $query->select()->from('produit_list_produit');
        return $query;
    }

    public function getProduits($formvars = array())
    {
        $query = $this->getProdQuery()->extras($formvars);

        if (!empty($this->produit_list_id)) {
            $query->where('plp.produit_list_id', $this->produit_list_id);
            $result = $this->sql->getAll($query->build());
        } else {
            $result = array();
        }

        return $result;
    }

    public function addProduit(\Produit $produit, \Attribut $attribut = null, $qte = 1)
    {
        $prod = $produit->toArray();
        if (is_null($attribut) == false) {
            $prod = array_merge($prod, $attribut->toArray());
        } elseif (!empty($prod['produit_attribut_id'])) {
            unset($prod['produit_attribut_id']);
        }
        $prod['produit_list_produit_qte'] = $qte;
        $this->produits[] = $prod;
    }

    public function save($data = null)
    {
        $id = parent::save($data);

        foreach ($this->produits as $produit) {
            $produit['produit_list_id'] = $id;
            $this->sql->save('produit_list_produit', $produit);
        }

        return $id;
    }

    public function deleteProduit($plpId)
    {
        if (empty($this->produit_list_id)) {
            throw new \DediException('no id list for delete produit');
        }

        $query = new \Query();
        $query->delete('produit_list_produit')->where('produit_list_produit_id', $plpId)
            ->where('produit_list_id', $this->produit_list_id);

        return $this->sql->query($query->build());

    }
}