<?php

declare(strict_types=1);

namespace Shopbydedi;

use Controller\ErrorController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class ErrorMiddleWare
 */
final class ErrorMiddleWare implements MiddlewareInterface
{
    /**
     * @var bool
     */
    private $showErrorMessage;

    /**
     * @var ErrorController
     */
    private $errorRenderer;

    /**
     * ErrorMiddleWare constructor.
     *
     * @param bool            $showErrorMessage
     * @param ErrorController $errorRenderer
     */
    public function __construct(bool $showErrorMessage, ErrorController $errorRenderer)
    {
        $this->showErrorMessage = $showErrorMessage;
        $this->errorRenderer = $errorRenderer;
    }

    /**
     * @param Request  $request
     * @param callable $handler
     *
     * @return Response
     * @throws \SmartyException
     */
    public function process(Request $request, callable $handler): Response
    {
        try {
            return $handler($request);
        } catch (\Throwable $exception) {
            foreach (explode("\n", (string)$exception) as $line) {
                \error_log($line);
            }

            return $this->errorRenderer->error_500(
                $this->showErrorMessage ? nl2br((string)$exception) : ""
            );
        }
    }
}