<?php

declare(strict_types=1);

namespace Shopbydedi;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class StackMiddleware
 */
final class StackMiddleware implements MiddlewareInterface
{
    /**
     * @var MiddlewareInterface[]
     */
    private $middlewares;

    /**
     * StackMiddleware constructor.
     *
     * @param MiddlewareInterface[] $middlewares
     */
    public function __construct(MiddlewareInterface ...$middlewares)
    {
        $this->middlewares = $middlewares;
    }

    /**
     * @param Request  $request
     * @param callable $handler
     *
     * @return Response
     * @throws \SmartyException
     */
    public function process(Request $request, callable $handler): Response
    {
        if (empty($this->middlewares)) {
            return $handler($request);
        }

        return $this->middlewares[0]->process($request, function (Request $request) use ($handler) {
            return $this->getPopped()->process($request, $handler);
        });
    }

    private function getPopped(): self
    {
        return new self(...array_slice($this->middlewares, 1));
    }
}